The `biogemeUtilities` is intended to add some quality-of-life features to the biogeme package. 
It inherit the features from biogeme, while adding some new functionality. 
The simplest way to use it, is to create a biogemeObject using the biogemeUtilities package, 
but it can also be used in existing script using biogemeObjects created directly in the biogeme package.
Examples of how to use this package are included below the relevant functions.

The full credit for the awesome biogeme package goes to Prof. Michel Bierlaire. 
Please visit the biogeme website for at full documentation of biogeme: https://biogeme.epfl.ch/